@@ -7,14 +7,15 @@
 #  file, You can obtain one at https://mozilla.org/MPL/2.0/.
 #  =========
 
-from discord import Message
-
 from mcdbot.errors.http_like_errors import ForbiddenError
 from mcdbot.helpers import check_user, check_mc_player_available, check_mc_password_validity_under_policy
 from mcdbot.mcdbot import Mcdbot
 # from mcdbot.redis import McStatus
 # from mcdbot.uuid import format_uuid, get_offline_player_uuid
 
+from discord import Message
+from loguru import logger
+
 
 async def register(main: Mcdbot, msg: Message, context, player: str, password: str):
     if check_user(main, msg.author):
@@ -39,6 +40,7 @@ async def register(main: Mcdbot, msg: Message, context, player: str, password: s
         if not await main.redis.create_player(player, msg.author):
             raise RuntimeError(f"user = {msg.author}, player = {player}")
         else:
+            logger.info(f"Registered player {player} belonging to {msg.author.id}.")
             return f"[OK] Registered player '{player}'."
     else:
         raise ForbiddenError
