@@ -12,12 +12,15 @@ from mcdbot.errors.object_errors import McPlayerNotFoundError
 from mcdbot.helpers import check_user
 from mcdbot.mcdbot import Mcdbot
 
+from loguru import logger
+
 
 async def unregister(main: Mcdbot, msg, context, player: str):
     if check_user(main, msg.author):
         if main.redis.get_player_by_user(msg.author) == player:
             await main.rcon.authme_unregister(player)
             await main.redis.del_player(player, msg.author)
+            logger.info(f"Unregistered {player} belonging to {msg.author.id}.")
         else:
             raise McPlayerNotFoundError
     else:
