@@ -9,7 +9,7 @@
 import sys
 
 from mcdbot import __version__, __source__, __issues__
-from datetime import datetime
+# from datetime import datetime
 
 
 class Final(object):
@@ -35,7 +35,7 @@ class Config(object):
                  api_token=None,
                  chore_loop_time=5,
                  ):
-        now = datetime.now()
+        # now = datetime.now()
 
         self.debug = debug
         self.rcon_address = rcon_address
@@ -56,7 +56,8 @@ class Config(object):
 
         self.mcdbot_log = mcdbot_log
         if self.mcdbot_log is None:
-            self.mcdbot_log = f"log-{now.isoformat(timespec='seconds')}-mcdbot.log"
+            # self.mcdbot_log = f"log-{now.isoformat(timespec='seconds')}-mcdbot.log"
+            self.mcdbot_log = "log-{time}-mcdbot.log"
         elif self.mcdbot_log == '[stdout]':
             self.mcdbot_log = sys.stdout
 
