@@ -40,7 +40,9 @@ class Mcdbot(discord.Client):
                                     level="DEBUG" if config.debug else "INFO",
                                     backtrace=True,
                                     diagnose=config.debug,
-                                    catch=False)
+                                    catch=False,
+                                    rotation="24h",
+                                    retention="2 weeks")
 
         import mcdbot.commands
         # from mcdbot.mojang_api import MojangApi
@@ -125,7 +127,13 @@ class Mcdbot(discord.Client):
     def turn_debug_on(self):
         # self.discord_logger.setLevel(logging.DEBUG)
         logger.remove(self.logger_id)
-        logger.add(global_config.mcdbot_log, level="DEBUG", backtrace=True, diagnose=True, catch=False)
+        logger.add(global_config.mcdbot_log,
+                   level="DEBUG",
+                   backtrace=True,
+                   diagnose=True,
+                   catch=False,
+                   rotation="24h",
+                   retention="2 weeks")
 
     def get_main_guild(self):
         return self.get_guild(global_config.main_guild_id)
